@@ -1,10 +1,5 @@
 package Perinci::Sub::GetArgs::Argv;
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-07-29'; # DATE
-our $DIST = 'Perinci-Sub-GetArgs-Argv'; # DIST
-our $VERSION = '0.846'; # VERSION
-
 use 5.010001;
 use strict;
 use warnings;
@@ -18,6 +13,11 @@ use List::Util qw(first);
 use Perinci::Sub::GetArgs::Array qw(get_args_from_array);
 use Perinci::Sub::Util qw(err);
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2021-09-30'; # DATE
+our $DIST = 'Perinci-Sub-GetArgs-Argv'; # DIST
+our $VERSION = '0.847'; # VERSION
+
 use Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(
@@ -1025,7 +1025,7 @@ sub get_args_from_argv {
                                     $_ = $decoded;
                                     last TRY_PARSING_AS_JSON_YAML;
                                 } else {
-                                    warn "Failed trying to parse argv #$i as JSON: $e";
+                                    #warn "Failed trying to parse argv #$i as JSON: $e";
                                 }
                             }
                             if ($per_arg_yaml) {
@@ -1034,7 +1034,7 @@ sub get_args_from_argv {
                                     $_ = $decoded;
                                     last TRY_PARSING_AS_JSON_YAML;
                                 } else {
-                                    warn "Failed trying to parse argv #$i as YAML: $e";
+                                    #warn "Failed trying to parse argv #$i as YAML: $e";
                                 }
                             }
                         }
@@ -1051,7 +1051,7 @@ sub get_args_from_argv {
                                 $val = $decoded;
                                 last TRY_PARSING_AS_JSON_YAML;
                             } else {
-                                warn "Failed trying to parse argv #$arg_spec->{pos} as JSON: $e";
+                                #warn "Failed trying to parse argv #$arg_spec->{pos} as JSON: $e";
                             }
                         }
                         if ($per_arg_yaml) {
@@ -1060,7 +1060,7 @@ sub get_args_from_argv {
                                 $val = $decoded;
                                 last TRY_PARSING_AS_JSON_YAML;
                             } else {
-                                warn "Failed trying to parse argv #$arg_spec->{pos} as YAML: $e";
+                                #warn "Failed trying to parse argv #$arg_spec->{pos} as YAML: $e";
                             }
                         }
                     }
@@ -1139,7 +1139,7 @@ Perinci::Sub::GetArgs::Argv - Get subroutine arguments from command line argumen
 
 =head1 VERSION
 
-This document describes version 0.846 of Perinci::Sub::GetArgs::Argv (from Perl distribution Perinci-Sub-GetArgs-Argv), released on 2021-07-29.
+This document describes version 0.847 of Perinci::Sub::GetArgs::Argv (from Perl distribution Perinci-Sub-GetArgs-Argv), released on 2021-09-30.
 
 =head1 SYNOPSIS
 
@@ -1467,14 +1467,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Su
 
 Source repository is at L<https://github.com/perlancar/perl-Perinci-Sub-GetArgs-Argv>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Perinci-Sub-GetArgs-Argv>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 L<Perinci>
@@ -1485,7 +1477,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Olivier Mengué perlancar (@pc-office) Steven Haryanto (on PC)
+=for stopwords Olivier Mengué Steven Haryanto (on PC)
 
 =over 4
 
@@ -1495,19 +1487,40 @@ Olivier Mengué <dolmen@cpan.org>
 
 =item *
 
-perlancar (@pc-office) <perlancar@gmail.com>
-
-=item *
-
 Steven Haryanto (on PC) <stevenharyanto@gmail.com>
 
 =back
 
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021, 2020, 2019, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2020, 2019, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Perinci-Sub-GetArgs-Argv>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
